@@ -46,9 +46,9 @@ class LXQT_API ConfigDialog : public QDialog
     Q_DECLARE_PRIVATE(ConfigDialog)
 
 public:
-    explicit ConfigDialog(const QString& title, Settings* settings, QWidget* parent = 0);
+    explicit ConfigDialog(const QString& title, Settings* settings, QWidget* parent = nullptr);
 
-    ~ConfigDialog();
+    ~ConfigDialog() override;
 
     /*!
      * Sets buttons in button bar
@@ -81,7 +81,7 @@ public:
      */
     void showPage(const QString &name);
 
-signals:
+Q_SIGNALS:
     /*!
      * This signal is emitted when the user pressed the "Reset" button.
      * Settings should be re-read and the widgets should be set accordingly.
@@ -101,8 +101,8 @@ signals:
 
 protected:
     Settings* mSettings;
-    virtual bool event(QEvent * event) override;
-    virtual void closeEvent(QCloseEvent* event) override;
+    bool event(QEvent * event) override;
+    void closeEvent(QCloseEvent* event) override;
 
 private:
     Q_DISABLE_COPY(ConfigDialog)
