@@ -2,7 +2,7 @@
  * (c)LGPL2+
  *
  * LXQt - a lightweight, Qt based, desktop toolset
- * http://razor-qt.org
+ * https://lxqt.org
  *
  * Copyright: 2010-2011 Razor team
  * Authors:
@@ -66,7 +66,7 @@ public:
     explicit PluginInfo();
 
     //! Reimplemented from XdgDesktopFile.
-    virtual bool load(const QString& fileName);
+    bool load(const QString& fileName) override;
 
 
     //! Reimplemented from XdgDesktopFile.
@@ -77,7 +77,7 @@ public:
     QString id() const { return mId; }
 
     //! This function is provided for convenience. It's equivalent to calling value("ServiceTypes").toString().
-    QString serviceType() const  { return value("ServiceTypes").toString(); }
+    QString serviceType() const  { return value(QL1S("ServiceTypes")).toString(); }
 
     //! Reimplemented from XdgDesktopFile.
     virtual bool isValid() const;
@@ -94,10 +94,10 @@ public:
 
       If the same filename is located under multiple directories only the first file should be used.
     */
-    static QList<PluginInfo> search(const QStringList& desktopFilesDirs, const QString& serviceType, const QString& nameFilter="*");
+    static QList<PluginInfo> search(const QStringList& desktopFilesDirs, const QString& serviceType, const QString& nameFilter = QLatin1String("*"));
 
     /// This function is provided for convenience. It's equivalent to new calling search(QString(desktopFilesDir), serviceType, nameFilter)
-    static QList<PluginInfo> search(const QString& desktopFilesDir, const QString& serviceType, const QString& nameFilter="*");
+    static QList<PluginInfo> search(const QString& desktopFilesDir, const QString& serviceType, const QString& nameFilter = QLatin1String("*"));
 
 private:
     QString mId;
